@@ -439,7 +439,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             self.l.append(resp)
             return self
 
-        dfs = data[ (data[ 'POSTCODE_AREA' ]==unit[ 'POSTCODE_AREA' ].astype(str).values[ 0 ]) & (data[ 'NUMBER_HEATED_ROOMS_e' ]==unit[ 'NUMBER_HEATED_ROOMS_e' ].astype(str).values[ 0 ])]
+        dfs = data[ (data[ 'POSTCODE_AREA' ].astype(str)==unit[ 'POSTCODE_AREA' ].astype(str).values[ 0 ]) & (data[ 'NUMBER_HEATED_ROOMS_e' ].astype(str)==unit[ 'NUMBER_HEATED_ROOMS_e' ].astype(str).values[ 0 ])]
 
         if len(dfs) < self.min_sample_sz:
             resp = pd.DataFrame({})
