@@ -121,19 +121,27 @@ def drop_outliers(data):
     return data
 
 
-def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15):
+def preprocess_data(data, drop_outliers=True, target='Price_p', test_size=0.15, split_data=True):
 
-    if drop_outlier:
+    if drop_outliers:
         data = drop_outliers(data)
 
-    match_types = ['1. Address Matched', '2. Address Matched No Spec', '3. No in Address Matched']
     keep_cols = [x for x in data.columns if '_e' in x or x in ['Longitude_m', 'Latitude_m', 'Postcode']]
-    keep_cols.append(target)
-    data = data[data['TypeOfMatching_m'].isin(match_types)]
+    if target in data.columns:
+        keep_cols.append(target)
+
+    try:
+        match_types = ['1. Address Matched', '2. Address Matched No Spec', '3. No in Address Matched']
+        data = data[data['TypeOfMatching_m'].isin(match_types)]
+    except: pass
+
     data = data[keep_cols]
-    data['POSTCODE'] = data['FULLADRESS_e'].apply(get_postcode_from_address)
-    data['POSTCODE_OUTCODE'] = data['Postcode'].apply(get_postcodeOutcode_from_postcode)
-    data['POSTCODE_AREA'] = data['POSTCODE_OUTCODE'].apply(get_postcodeArea_from_outcode)
+
+    try:
+        data['POSTCODE'] = data['FULLADRESS_e'].apply(get_postcode_from_address)
+        data['POSTCODE_OUTCODE'] = data['Postcode'].apply(get_postcodeOutcode_from_postcode)
+        data['POSTCODE_AREA'] = data['POSTCODE_OUTCODE'].apply(get_postcodeArea_from_outcode)
+    except: pass
 
     # drop outliers, convert floor level to integers
     data['Rooms'] = (data['NUMBER_HABITABLE_ROOMS_e'].astype(float) + data['NUMBER_HEATED_ROOMS_e'].astype(
@@ -171,17 +179,29 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15):
         float)
     data['NUMBER_HEATED_ROOMS_e'] = data['NUMBER_HEATED_ROOMS_e'].astype(str).replace('nan', np.nan).fillna('0').astype(
         float)
-    data = data[['POSTCODE',
-                 'POSTCODE_OUTCODE',
-                 'POSTCODE_AREA',
-                 'POSTTOWN_e',
-                 'PROPERTY_TYPE_e',
-                 'TOTAL_FLOOR_AREA_e',
-                 'NUMBER_HEATED_ROOMS_e',
-                 'FLOOR_LEVEL_e',
-                 'Latitude_m',
-                 'Longitude_m',
-                 target]]
+    if target in data.columns:
+        data = data[['POSTCODE',
+                     'POSTCODE_OUTCODE',
+                     'POSTCODE_AREA',
+                     'POSTTOWN_e',
+                     'PROPERTY_TYPE_e',
+                     'TOTAL_FLOOR_AREA_e',
+                     'NUMBER_HEATED_ROOMS_e',
+                     'FLOOR_LEVEL_e',
+                     'Latitude_m',
+                     'Longitude_m',
+                     target]]
+    else:
+        data = data[['POSTCODE',
+                     'POSTCODE_OUTCODE',
+                     'POSTCODE_AREA',
+                     'POSTTOWN_e',
+                     'PROPERTY_TYPE_e',
+                     'TOTAL_FLOOR_AREA_e',
+                     'NUMBER_HEATED_ROOMS_e',
+                     'FLOOR_LEVEL_e',
+                     'Latitude_m',
+                     'Longitude_m']]
 
     data = data.reset_index()
     data = data.drop('index', axis=1)
@@ -192,7 +212,13 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15):
     data['TOTAL_FLOOR_AREA_e'] = data['TOTAL_FLOOR_AREA_e'].astype(float)
     data['FLOOR_LEVEL_e'] = data['FLOOR_LEVEL_e'].astype(float)
     data['NUMBER_HEATED_ROOMS_e'] = data['NUMBER_HEATED_ROOMS_e'].astype(float)
-    data[target] = data[target].astype(float)
+
+    if target in data.columns:
+        data[target] = data[target].astype(float)
+
+    if not split_data:
+        return data
+
     X = data.drop('POSTCODE_AREA', axis=1)
     y = data['POSTCODE_AREA']
     X_train, X_holdout, y_train, y_holdout = bciavm.preprocessing.utils.split_data(X, y, problem_type='multiclass',
